### Challenge

Reproduce MLPerf inference v3.0 benchmark results for Nvidia Jetson Orin
(performance, accuracy,power) and automate it using the 
[MLCommons CK framework](https://github.com/mlcommons/ck).

### Organizers

* [MLCommons taskforce on automation and reproducibility](https://cKnowledge.org/mlcommons-taskforce)
* [cTuning foundation](https://cTuning.org)
* [cKnowledge](https://cKnowledge.org)

### Status

Finished. Preliminary results are available [here](https://github.com/mlcommons/ck/blob/master/cm-mlops/challenge/optimize-mlperf-inference-v3.0-2023/docs/setup-nvidia-jetson-orin.md).

